@@ -11,38 +11,13 @@
  *
  *      $RCSfile: AtomRep.h,v $
  *      $Author: billh $        $Locker:  $                $State: Exp $
- *      $Revision: 1.6 $      $Date: 95/03/24 18:47:04 $
+ *      $Revision: 1.9 $      $Date: 1995/05/11 21:36:16 $
  *
  ***************************************************************************
  * DESCRIPTION:
  * 
  * Parse and maintain the data for how a molecule should be represented.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	AtomRep.h,v $
- * Revision 1.6  95/03/24  18:47:04  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.5  1994/12/11  01:14:47  dalke
- * Added ribbons - warning - it workds, bu the ribbon interface
- *  WILL change
- *
- * Revision 1.4  1994/11/03  01:03:05  billh
- * Changed text and enum name for 'off' option in atom representation.
- *
- * Revision 1.3  1994/11/02  23:32:44  billh
- * Added 'none' option to AtomRep to quickly turn off graphics reps
- *
- * Revision 1.2  1994/10/26  23:19:44  billh
- * Removed 'ok' member; removed initial string in constructor; added 'cmd_parse'
- * and operator= routines, as well as 'change' routine.
- *
- * Revision 1.1  94/09/23  06:01:39  billh
- * Initial revision
- * 
  ***************************************************************************/
 #ifndef ATOMREP_H
 #define ATOMREP_H
@@ -58,7 +33,8 @@ class AtomRep {
 
 public:
   // different methods for representing atoms
-  enum RepMethod { LINES, CPK, VDW, DOTTED, LICORICE, RIBBONS, REPOFF, TOTAL };
+  enum RepMethod { LINES, BONDS, CPK, POINTS, VDW, DOTTED, LICORICE, RIBBONS, 
+		   TUBE, REPOFF, TOTAL };
 
   // initial string with representation command
   char cmdStr[MAX_ATOMREP_CMD + 1];
@@ -110,3 +86,38 @@ public:
 extern char *AtomRepName[AtomRep::TOTAL];
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: AtomRep.h,v $
+ * Revision 1.9  1995/05/11  21:36:16  billh
+ * Moved log message to end of file.
+ *
+ * Revision 1.8  95/04/28  04:47:44  dalke
+ * Added 'bonds' and 'points'
+ * 
+ * Revision 1.7  1995/04/08  06:38:10  dalke
+ * added tube representation
+ *
+ * Revision 1.6  1995/03/24  18:47:04  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ *
+ * Revision 1.5  1994/12/11  01:14:47  dalke
+ * Added ribbons - warning - it workds, bu the ribbon interface
+ *  WILL change
+ *
+ * Revision 1.4  1994/11/03  01:03:05  billh
+ * Changed text and enum name for 'off' option in atom representation.
+ *
+ * Revision 1.3  1994/11/02  23:32:44  billh
+ * Added 'none' option to AtomRep to quickly turn off graphics reps
+ *
+ * Revision 1.2  1994/10/26  23:19:44  billh
+ * Removed 'ok' var; removed initial string in constructor; added 'cmd_parse'
+ * and operator= routines, as well as 'change' routine.
+ *
+ * Revision 1.1  94/09/23  06:01:39  billh
+ * Initial revision
+ * 
+ ***************************************************************************/
