@@ -11,7 +11,7 @@
  *
  *	$RCSfile: CaveScene.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.6 $	$Date: 95/03/24 18:47:33 $
+ *	$Revision: 1.7 $	$Date: 1995/05/12 00:39:28 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -19,33 +19,12 @@
  * shared memory arena, since the display lists are shared amoung
  * the different machines
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	CaveScene.h,v $
- * Revision 1.6  95/03/24  18:47:33  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.5  1994/11/10  17:02:35  billh
- * Removed Semaphore.h include; .C includes Inform header.
- *
- * Revision 1.4  1994/11/09  22:40:01  dalke
- * Added blocks for rendering procs.
- *
- * Revision 1.3  1994/11/09  05:20:45  dalke
- * moved functions to their "proper" virtual functions
- *
- * Revision 1.2  1994/11/08  06:35:57  dalke
- * Alpha works with newest CAVE library and new CaveScene
- *
  ***************************************************************************/
 #ifndef CAVE_SCENE_H
 #define CAVE_SCENE_H
 
 #include "Scene.h"
 #include "CaveResizeArray.h"
-#include "cave.h"
 
 // This needs to grab shared memory for use in the CAVE
 // environment.  It does it with two means.
@@ -117,7 +96,7 @@ public:
   // deal with command list storage, and registration of Displayables
   //
   
-  // (un)register the given Displayable & corresponding display list (of dim D)
+  // (un)register the given Displayable & corresponding display list 
   virtual void Register(Displayable *, char *, int);
   virtual void unRegister(Displayable *, char *, int);
 
@@ -129,4 +108,29 @@ public:
   
   // and that should be all she wrote on this end
 };
+
 #endif /* CAVE_SCENE_H */
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: CaveScene.h,v $
+ * Revision 1.7  1995/05/12  00:39:28  billh
+ * Moved log messages to end of file.
+ *
+ * Revision 1.6  95/03/24  18:47:33  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.5  1994/11/10  17:02:35  billh
+ * Removed Semaphore.h include; .C includes Inform header.
+ *
+ * Revision 1.4  1994/11/09  22:40:01  dalke
+ * Added blocks for rendering procs.
+ *
+ * Revision 1.3  1994/11/09  05:20:45  dalke
+ * moved functions to their "proper" virtual functions
+ *
+ * Revision 1.2  1994/11/08  06:35:57  dalke
+ * Alpha works with newest CAVE library and new CaveScene
+ *
+ ***************************************************************************/
