@@ -11,7 +11,7 @@
  *
  *	$RCSfile: CaveTracker.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.2 $	$Date: 95/03/24 18:47:36 $
+ *	$Revision: 1.3 $	$Date: 1995/05/12 00:39:30 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -19,10 +19,36 @@
  * A CaveTracker is a device for measuring the 3D spacial position of the
  * Cave input device; it is a subclass of the Tracker class.
  *
- ***************************************************************************
- * REVISION HISTORY:
+ ***************************************************************************/
+#ifndef CAVETRACKER_H
+#define CAVETRACKER_H
+
+// project include files
+#include "Tracker.h"
+
+
+class CaveTracker : public Tracker {
+
+protected:
+  // virtual routine which reads data from sensors, if available
+  // returns TRUE if data read and variables changed, FALSE otherwise;
+  virtual int my_get_data(int, float *, float *, float *, float *, int);
+
+public:
+  // constructors and destructors
+  CaveTracker(char *name, int num_sensors = 1);
+  virtual ~CaveTracker(void);
+
+};
+
+#endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: CaveTracker.h,v $
+ * Revision 1.3  1995/05/12  00:39:30  billh
+ * Moved log messages to end of file.
  *
- * $Log:	CaveTracker.h,v $
  * Revision 1.2  95/03/24  18:47:36  billh
  * Added copyright notice to top of file; made sure all virtual routines
  * are defined in the .C file, not in the .h file.
@@ -43,25 +69,3 @@
  * Changed program name to vmd, added RCS header section.
  *
  ***************************************************************************/
-
-#ifndef CAVETRACKER_H
-#define CAVETRACKER_H
-// project include files
-#include "Tracker.h"
-#include "cave.h"
-
-class CaveTracker : public Tracker {
-
-protected:
-  // virtual routine which reads data from sensors, if available
-  // returns TRUE if data read and variables changed, FALSE otherwise;
-  virtual int my_get_data(int, float *, float *, float *, float *, int);
-
-public:
-  // constructors and destructors
-  CaveTracker(char *name, int num_sensors = 1);
-  virtual ~CaveTracker(void);
-
-};
-
-#endif
