@@ -11,23 +11,12 @@
  *
  *	$RCSfile: CmdExternal.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.2 $	$Date: 95/03/24 18:47:47 $
+ *	$Revision: 1.3 $	$Date: 1995/05/11 22:05:46 $
  *
  ***************************************************************************
  * DESCRIPTION:
  *  Turn the UIExternal either on or off
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	CmdExternal.h,v $
- * Revision 1.2  95/03/24  18:47:47  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.1  1995/02/22  08:55:55  dalke
- * Initial revision
- *
  ***************************************************************************/
 #ifndef CMDEXTERNAL_H
 #define CMDEXTERNAL_H
@@ -37,11 +26,16 @@
 
 // The following use "EXTERNAL_START" and "EXTERNAL_END"
 
+// text callback routine for 'external'
+extern int text_cmd_external(int, char **, CommandQueue *, int);
+
+
 ////////////////////// start a new external interface
 class CmdExternalStart : public Command {
 
 protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
 
 public:
   CmdExternalStart(int = -1);
@@ -54,11 +48,28 @@ class CmdExternalEnd : public Command {
 
 protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
 
 public:
   CmdExternalEnd(int = -1);
 
 };
 
-
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: CmdExternal.h,v $
+ * Revision 1.3  1995/05/11  22:05:46  billh
+ * Added 'create_text' function to create text representation "on demand".
+ * Added text callback functions which are added by UIText, and which are
+ * called when a text command is entered and the first word is recognized.
+ *
+ * Revision 1.2  95/03/24  18:47:47  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.1  1995/02/22  08:55:55  dalke
+ * Initial revision
+ *
+ ***************************************************************************/
