@@ -11,7 +11,7 @@
  *
  *      $RCSfile: CmdLabel.h,v $
  *      $Author: billh $        $Locker:  $                $State: Exp $
- *      $Revision: 1.2 $      $Date: 95/03/24 18:47:50 $
+ *      $Revision: 1.3 $      $Date: 1995/05/11 22:05:48 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -19,27 +19,19 @@
  * Command objects used to create, list, delete, or graph labels for measuring
  * geometries.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	CmdLabel.h,v $
- * Revision 1.2  95/03/24  18:47:50  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.1  1995/03/04  05:33:08  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef CMDLABEL_H
 #define CMDLABEL_H
 
 #include "Command.h"
-extern class Geometry;
+class Geometry;
 
 // The following uses the Cmdtypes LABEL_ADD, LABEL_SHOW, LABEL_LIST,
 // LABEL_GRAPH and LABEL_DELETE from the Command class
 
+// text callback routine for 'label'
+extern int text_cmd_label(int, char **, CommandQueue *, int);
+
 
 ////////////////////// add a new label 
 class CmdLabelAdd : public Command {
@@ -49,6 +41,7 @@ private:
   
 protected:
   virtual int do_execute(void) ;
+  virtual void create_text(void);
 
 public:
   // constructor: category name, # items, item strings
@@ -63,6 +56,7 @@ private:
 
 protected:
   virtual int do_execute(void) ;
+  virtual void create_text(void);
 
 public:
   // constructor: category name
@@ -74,11 +68,12 @@ public:
 class CmdLabelShow : public Command {
 private:
   int cat;		// category to toggle
-  int item;		// which item to toggle (if < 0, toggle entire category)
+  int item;		// which item to toggle (if < 0 toggle entire cat.)
   int show;		// if T, turn on; if F, turn off
 
 protected:
   virtual int do_execute(void) ;
+  virtual void create_text(void);
 
 public:
   // constructor: category name, show, item
@@ -90,9 +85,11 @@ public:
 class CmdLabelDelete : public Command {
 private:
   int cat;		// category to delete from
-  int item;		// which item to delete (if < 0 delete all in category)
+  int item;		// which item to delete (if < 0 delete all in cat.)
+
 protected:
   virtual int do_execute(void) ;
+  virtual void create_text(void);
 
 public:
   // constructor: category name, item
@@ -100,7 +97,7 @@ public:
 };
 
 
-////////////////////// graph the values for the Nthe label in the given category
+////////////////// graph the values for the Nthe label in the given category
 class CmdLabelGraph : public Command {
 private:
   int cat;		// category to delete from
@@ -109,6 +106,7 @@ private:
   			// echo the data to the console
 protected:
   virtual int do_execute(void) ;
+  virtual void create_text(void);
 
 public:
   // constructor: category name, item
@@ -117,3 +115,20 @@ public:
 
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: CmdLabel.h,v $
+ * Revision 1.3  1995/05/11  22:05:48  billh
+ * Added 'create_text' function to create text representation "on demand".
+ * Added text callback functions which are added by UIText, and which are
+ * called when a text command is entered and the first word is recognized.
+ *
+ * Revision 1.2  95/03/24  18:47:50  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.1  1995/03/04  05:33:08  billh
+ * Initial revision
+ *
+ ***************************************************************************/
