@@ -11,44 +11,37 @@
  *
  *      $RCSfile: CmdRemote.h,v $
  *      $Author: billh $        $Locker:  $                $State: Exp $
- *      $Revision: 1.3 $      $Date: 95/03/24 18:48:04 $
+ *      $Revision: 1.4 $      $Date: 1995/05/11 22:06:13 $
  *
  ***************************************************************************
  * DESCRIPTION:
  * 
  * Command objects for affecting remote connections.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	CmdRemote.h,v $
- * Revision 1.3  95/03/24  18:48:04  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.2  1994/10/21  03:50:45  billh
- * Updated for new simulation control commands, and remoteList object.
- *
- * Revision 1.1  1994/10/01  11:04:31  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef CMDREMOTE_H
 #define CMDREMOTE_H
 
 #include "Command.h"
 
-
 // the following uses the Cmdtypes REMOTE_INIT, REMOTE_CANCEL, REMOTE_LIST,
 //	REMOTE_NEW, REMOTE_ATTACH, REMOTE_RUN, REMOTE_SETOPT, REMOTE_READOPT,
 //	REMOTE_WRITEOPT,
 //	SIM_SETPARAM, SIM_PATCHDISP, SIM_TOP, SIM_DETACH, SIM_KILL, SIM_LIST
 
+// text callback routine for 'remote' and 'sim'
+extern int text_cmd_remote(int, char **, CommandQueue *, int);
+extern int text_cmd_sim(int, char **, CommandQueue *, int);
+
+
 ///////////// initialize remote with a new connection
 class CmdRemoteInit : public Command {
-protected:
+private:
   char *username, *computer;	// username and computer to use
+
+protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
   
 public:
   CmdRemoteInit(char *, char *, int=(-1));
@@ -60,7 +53,8 @@ public:
 class CmdRemoteCancel : public Command {
 protected:
   virtual int do_execute(void);
-  
+  virtual void create_text(void);
+
 public:
   CmdRemoteCancel(int=(-1));
 };
@@ -72,9 +66,12 @@ public:
   // what to list (default is ALL)
   enum RemoteList { ALL, JOBS, APPS, PARAMS };
 
-protected:
+private:
   RemoteList whatToList;		// what should be displayed?
+
+protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
 
 public:
   CmdRemoteList(RemoteList, int=(-1));
@@ -86,9 +83,12 @@ public:
 /////////////// app.  App is an index into the list of possible applications
 /////////////// that can be started.
 class CmdRemoteNew : public Command {
-protected:
+private:
   int whichApp;			// index of application to select
+
+protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
 
 public:
   CmdRemoteNew(int, int=(-1));
@@ -99,9 +99,12 @@ public:
 /////////////// running job ... a new molecule will be created if this is
 /////////////// successful
 class CmdRemoteAttach : public Command {
-protected:
+private:
   int whichJob;			// index of job to attach to
+
+protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
 
 public:
   CmdRemoteAttach(int, int=(-1));
@@ -114,6 +117,7 @@ public:
 class CmdRemoteRun : public Command {
 protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
 
 public:
   CmdRemoteRun(int=(-1));
@@ -124,10 +128,13 @@ public:
 /////////////// remote simulation being set up.  Only works if parameters
 /////////////// are being edited.
 class CmdRemoteSetopt : public Command {
-protected:
+private:
   char *keyword;			// or, can use a keyword to specify
   char *paramVal;			// new value for parameter
+
+protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
 
 public:
   CmdRemoteSetopt(char *, char *, int=(-1));
@@ -139,9 +146,12 @@ public:
 /////////////// Only works if a CmdRemoteNew command has been
 /////////////// executed previously
 class CmdRemoteReadopt : public Command {
-protected:
+private:
   char *fname;				// name of file
+
+protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
 
 public:
   CmdRemoteReadopt(char *, int=(-1));
@@ -153,9 +163,12 @@ public:
 /////////////// This will work as long as the current remote object has
 /////////////// any parameters to write.
 class CmdRemoteWriteopt : public Command {
-protected:
+private:
   char *fname;				// name of file
+
+protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
 
 public:
   CmdRemoteWriteopt(char *, int=(-1));
@@ -165,10 +178,14 @@ public:
 
 /////////////// issue command to change parameter for top remote connection.
 class CmdRemoteChangeParam : public Command {
-protected:
+private:
   char *param;				// which parameter
   char *newval;				// new value
+
+protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
+
 public:
   CmdRemoteChangeParam(char *, char *, int=(-1));
   virtual ~CmdRemoteChangeParam(void);
@@ -177,9 +194,13 @@ public:
 
 /////////////// change how patches are displayed (if they are even available)
 class CmdRemotePatchDisplay : public Command {
-protected:
+private:
   int newval;			// new display setting
+
+protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
+
 public:
   CmdRemotePatchDisplay(char *, int=(-1));
   CmdRemotePatchDisplay(int, int=(-1));
@@ -188,9 +209,13 @@ public:
 
 /////////////// set the specified molecule as the top remote connection
 class CmdRemoteTop : public Command {
-protected:
+private:
   int id;			// which molecule to make top (ID of molecule)
+
+protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
+
 public:
   CmdRemoteTop(int, int=(-1));
 };
@@ -198,9 +223,13 @@ public:
 
 /////////////// detach from a running simulation, but don't kill it
 class CmdRemoteDetach : public Command {
-protected:
+private:
   int id;			// which molecule to detach (ID of molecule)
+
+protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
+
 public:
   CmdRemoteDetach(int, int=(-1));
 };
@@ -208,9 +237,13 @@ public:
 
 /////////////// kill a running simulation
 class CmdRemoteKill : public Command {
-protected:
+private:
   int id;			// which molecule to kill (ID of molecule)
+
+protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
+
 public:
   CmdRemoteKill(int, int=(-1));
 };
@@ -220,9 +253,31 @@ public:
 class CmdRemoteSimList : public Command {
 protected:
   virtual int do_execute(void);
+  virtual void create_text(void);
+
 public:
   CmdRemoteSimList(int=(-1));
 };
 
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: CmdRemote.h,v $
+ * Revision 1.4  1995/05/11  22:06:13  billh
+ * Added 'create_text' function to create text representation "on demand".
+ * Added text callback functions which are added by UIText, and which are
+ * called when a text command is entered and the first word is recognized.
+ *
+ * Revision 1.3  95/03/24  18:48:04  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.2  1994/10/21  03:50:45  billh
+ * Updated for new simulation control commands, and remoteList object.
+ *
+ * Revision 1.1  1994/10/01  11:04:31  billh
+ * Initial revision
+ *
+ ***************************************************************************/
