@@ -11,7 +11,7 @@
  *
  *	$RCSfile: ColorList.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.9 $	$Date: 1995/03/28 03:37:54 $
+ *	$Revision: 1.10 $	$Date: 1995/05/11 22:10:58 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -20,53 +20,13 @@
  * them.  Each Displayable must turn on or off material characteristics
  * if needed, and say which color to use.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log: ColorList.h,v $
- * Revision 1.9  1995/03/28  03:37:54  billh
- * Added a few more built-in residues.
- * Make black an 'extra' color; the first 16 colors are 'visible' colors,
- * which are used to color molecules such that black is not assigned
- * as a color for an unknown segment or residue name, etc.
- *
- * Revision 1.8  95/03/24  18:48:23  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.7  1995/03/09  00:19:46  dalke
- * added way to get index nearest to an rgb triplet
- *
- * Revision 1.6  1994/12/07  03:18:55  dalke
- * Added Black/white option for a range
- *
- * Revision 1.5  1994/12/06  08:32:25  billh
- * Added reset_color routine, which sets the colors to their default
- * values.
- * Changed ICEBLUE color to BLACK; ICEBLUE objects now CYAN.
- *
- * Revision 1.4  94/12/05  08:25:47  billh
- * Added public member colorNames with string names for the regular colors.
- * Added many options for changing how the color scale is done.
- * 
- * Revision 1.3  94/10/01  03:03:59  billh
- * Removed 'update' routine.
- * 
- * Revision 1.2  94/09/24  20:27:17  billh
- * Added color category NameList's, which are used by the AtomColor
- * object to determine the color for each atom, and which are used to
- * change the color for different items.
- * 
- * Revision 1.1  1994/08/24  03:10:37  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef COLORLIST_H
 #define COLORLIST_H
 
 #include "Displayable.h"
 #include "NameList.h"
-extern class DispCmdColorDef;
+class DispCmdColorDef;
 
 // total number of colors defined here
 #define REGCLRS		17
@@ -124,8 +84,6 @@ extern class DispCmdColorDef;
 #define MAPCOLOR(a)		(a + BEGMAP)
 #define MAPTRANSLUCENT(a)	(a + BEGTRANMAP)
 
-typedef NameList<int> *NameListIntPtr;
-
 
 class ColorList : public Displayable3D {
 
@@ -248,3 +206,47 @@ public:
 extern char *colorScaleMethod[ColorList::SCALE_TOTAL];
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: ColorList.h,v $
+ * Revision 1.10  1995/05/11  22:10:58  billh
+ * Moved log messages to end of file.
+ *
+ * Revision 1.9  95/03/28  03:37:54  billh
+ * Added a few more built-in residues.
+ * Make black an 'extra' color; the first 16 colors are 'visible' colors,
+ * which are used to color molecules such that black is not assigned
+ * as a color for an unknown segment or residue name, etc.
+ * 
+ * Revision 1.8  95/03/24  18:48:23  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.7  1995/03/09  00:19:46  dalke
+ * added way to get index nearest to an rgb triplet
+ *
+ * Revision 1.6  1994/12/07  03:18:55  dalke
+ * Added Black/white option for a range
+ *
+ * Revision 1.5  1994/12/06  08:32:25  billh
+ * Added reset_color routine, which sets the colors to their default
+ * values.
+ * Changed ICEBLUE color to BLACK; ICEBLUE objects now CYAN.
+ *
+ * Revision 1.4  94/12/05  08:25:47  billh
+ * Added public member colorNames with string names for the regular colors.
+ * Added many options for changing how the color scale is done.
+ * 
+ * Revision 1.3  94/10/01  03:03:59  billh
+ * Removed 'update' routine.
+ * 
+ * Revision 1.2  94/09/24  20:27:17  billh
+ * Added color category NameList's, which are used by the AtomColor
+ * object to determine the color for each atom, and which are used to
+ * change the color for different items.
+ * 
+ * Revision 1.1  1994/08/24  03:10:37  billh
+ * Initial revision
+ *
+ ***************************************************************************/
