@@ -11,7 +11,7 @@
  *
  *	$RCSfile: ColorUser.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.2 $	$Date: 95/03/24 18:48:25 $
+ *	$Revision: 1.3 $	$Date: 1995/05/11 22:11:01 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -23,22 +23,11 @@
  * "color objects" to the category with an identifying name.  The user can
  * edit these colors via commands.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	ColorUser.h,v $
- * Revision 1.2  95/03/24  18:48:25  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.1  1994/12/06  08:36:55  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef COLORUSER
 #define COLORUSER
 
-extern class ColorList;
+class ColorList;
 
 
 class ColorUser {
@@ -78,3 +67,17 @@ public:
 
 #endif
 
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: ColorUser.h,v $
+ * Revision 1.3  1995/05/11  22:11:01  billh
+ * Moved log messages to end of file.
+ *
+ * Revision 1.2  95/03/24  18:48:25  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.1  1994/12/06  08:36:55  billh
+ * Initial revision
+ *
+ ***************************************************************************/
