@@ -11,7 +11,7 @@
  *
  *	$RCSfile: ConfigList.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.3 $	$Date: 95/03/24 18:48:32 $
+ *	$Revision: 1.4 $	$Date: 1995/05/12 00:39:32 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -39,24 +39,9 @@
  *   Keywords are case INsensitive
  *   In this version of ConfigList, only ONE keyword/data pair is kept,
  * the last one read.  All previous ones are deleted.
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	ConfigList.h,v $
- * Revision 1.3  95/03/24  18:48:32  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.2  1994/11/02  06:58:32  billh
- * Fixed small problem with comment header.
- *
- * Revision 1.1  1994/11/02  05:17:53  dalke
- * Initial revision
- *
- *
- * Taken from namd's ConfigList.h version 1.2
- * 
  ***************************************************************************/
+#ifndef CONFIGLIST_H
+#define CONFIGLIST_H
 
 // This header introduces two names to the global name space
 // They are:
@@ -66,11 +51,10 @@
 //      format "keyword = data" and creates a listing of all the data
 //      for each keyword.  This data can be retreived with "find(char *)"
 
-#ifndef CONFIGLIST_H
-#define CONFIGLIST_H
-#include "Inform.h"
-#include "Global.h"
 #include <string.h>
+#include "Inform.h"
+#include "utilities.h"
+
 
 typedef struct StringList {
   char *data;
@@ -87,8 +71,9 @@ typedef struct StringList {
   }
 } StringList;
 
+
 class ConfigList {
-  private:
+  public:
     typedef struct ConfigListNode {
       char *name;
       StringList *data;
@@ -104,18 +89,20 @@ class ConfigList {
         delete [] name;                  // delete the new'ed name
         name = NULL;
         next = NULL;
-        StringList *curr, *next;        // go through the string list
+        StringList *curr, *next=NULL;        // go through the string list
         for (curr= data; curr!=NULL; curr = next) {
           next = curr -> next;           // and delete each element
           delete curr;
         }
       }
     } ConfigListNode;
-    
+
+  private:
     ConfigListNode *theList;
        // copy the information into a String, as appropriate
     void add_element( char *s1, int len1, char *s2, int len2);
     ConfigListNode *find_key_word( const char *keyword);
+
   public:
     ConfigList( void);
     ~ConfigList( void);
@@ -126,9 +113,29 @@ class ConfigList {
        //   and any changed you make will be permanent.
        
     ConfigListNode *head( void) { return theList;  } // return everything
-       // NOTE:  you _REALLY_ not not want to change the information
+       // NOTE:  you _REALLY_ do not want to change the information
        //   you get from this (unless you really want to)
 };
 
-
 #endif // CONFIGLIST_H
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: ConfigList.h,v $
+ * Revision 1.4  1995/05/12  00:39:32  billh
+ * Moved log messages to end of file.
+ *
+ * Revision 1.3  95/03/24  18:48:32  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.2  1994/11/02  06:58:32  billh
+ * Fixed small problem with comment header.
+ *
+ * Revision 1.1  1994/11/02  05:17:53  dalke
+ * Initial revision
+ *
+ *
+ * Taken from namd's ConfigList.h version 1.2
+ * 
+ ***************************************************************************/
