@@ -11,7 +11,7 @@
  *
  *	$RCSfile: CoorDCD.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.2 $	$Date: 95/03/24 18:48:37 $
+ *	$Revision: 1.3 $	$Date: 1995/05/11 22:23:44 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -28,23 +28,12 @@
  * NOTE: currently, this supports only BINARY format.  ASCII uses that
  * strange 12Z6 fortran format, which is a pain to deal with.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	CoorDCD.h,v $
- * Revision 1.2  95/03/24  18:48:37  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.1  1994/09/17  09:11:36  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef DCDCOORFILE_H
 #define DCDCOORFILE_H
 
 #include "CoorFile.h"
-extern class BaseMolecule;
+class BaseMolecule;
 
 // error flag values; should be > 0
 #define DCD_ERR_NOTOPEN		1
@@ -184,3 +173,18 @@ public:
 };
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: CoorDCD.h,v $
+ * Revision 1.3  1995/05/11  22:23:44  billh
+ * Moved log messages to the end of the file.
+ *
+ * Revision 1.2  95/03/24  18:48:37  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.1  1994/09/17  09:11:36  billh
+ * Initial revision
+ *
+ ***************************************************************************/
