@@ -11,7 +11,7 @@
  *
  *	$RCSfile: CoorFile.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.3 $	$Date: 95/03/24 18:48:39 $
+ *	$Revision: 1.4 $	$Date: 1995/05/11 22:23:46 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -20,20 +20,6 @@
  * Subclasses must provide methods for opening and closing files,
  * and for reading/writing coordinates.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	CoorFile.h,v $
- * Revision 1.3  95/03/24  18:48:39  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.2  1994/11/21  14:45:09  billh
- * No change.
- *
- * Revision 1.1  94/09/17  09:11:36  billh
- * Initial revision
- * 
  ***************************************************************************/
 #ifndef COORFILE_H
 #define COORFILE_H
@@ -43,7 +29,7 @@
 #include <unistd.h>
 #include <pwd.h>
 #include "utilities.h"
-extern class Timestep;
+class Timestep;
 
 // max number of comment lines that will be kept
 #define MAX_COOR_REM	10
@@ -167,3 +153,21 @@ public:
 };
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: CoorFile.h,v $
+ * Revision 1.4  1995/05/11  22:23:46  billh
+ * Moved log messages to the end of the file.
+ *
+ * Revision 1.3  95/03/24  18:48:39  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.2  1994/11/21  14:45:09  billh
+ * No change.
+ *
+ * Revision 1.1  94/09/17  09:11:36  billh
+ * Initial revision
+ * 
+ ***************************************************************************/
