@@ -11,7 +11,7 @@
  *
  *	$RCSfile: CoorPDB.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.3 $	$Date: 95/03/24 18:48:46 $
+ *	$Revision: 1.4 $	$Date: 1995/05/11 22:23:50 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -23,26 +23,12 @@
  * BaseMolecule must be specified, so that the structure can be properly
  * compared.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	CoorPDB.h,v $
- * Revision 1.3  95/03/24  18:48:46  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.2  1994/12/11  01:16:23  dalke
- * Added provision for other functions to reference the PDB write
- *
- * Revision 1.1  1994/09/17  09:11:36  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef PDBCOORFILE_H
 #define PDBCOORFILE_H
 
 #include "CoorFile.h"
-extern class BaseMolecule;
+class BaseMolecule;
 
 // error flag values; should be > 0
 #define COOR_ERR_NOTOPEN	1
@@ -121,3 +107,21 @@ void write_raw_pdb_record(FILE *outfile, char *recordname, int index,
     float z, float occ, float beta, char *segname);
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: CoorPDB.h,v $
+ * Revision 1.4  1995/05/11  22:23:50  billh
+ * Moved log messages to the end of the file.
+ *
+ * Revision 1.3  95/03/24  18:48:46  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.2  1994/12/11  01:16:23  dalke
+ * Added provision for other functions to reference the PDB write
+ *
+ * Revision 1.1  1994/09/17  09:11:36  billh
+ * Initial revision
+ *
+ ***************************************************************************/
