@@ -11,7 +11,7 @@
  *
  *	$RCSfile: DisplayDevice.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.10 $	$Date: 95/03/24 18:48:59 $
+ *	$Revision: 1.11 $	$Date: 1995/05/11 22:37:26 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -20,50 +20,6 @@
  *	can process a list of drawing commands and render the drawing
  *	to some device (screen, file, preprocessing script, etc.)
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	DisplayDevice.h,v $
- * Revision 1.10  95/03/24  18:48:59  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.9  1995/02/22  04:03:10  billh
- * Added virtual routine pick, which checks the given draw list for points
- * which can be selected.  Also added routines to convert absolute screen
- * coords <--> relative scaled screen coords.
- * Added virtual routine find_3D_from_2D, which takes a 3D point at pos A,
- * and 2D rel screen position at B, and returns the 3D point corresponding
- * to the 2D point at B in the same plane as point A.
- *
- * Revision 1.8  94/12/06  08:24:25  billh
- * Added ability to create color categories, due to being now derived from
- * ColorUser.
- * Added routines to have a new color list specified, and to check for when
- * a color in a relevant category is changed.
- * 
- * Revision 1.7  94/11/09  03:45:28  billh
- * Provided default versions for all virtual functions, so an 'empty' display
- * can be created that does essentially nothing (for testing purposes).
- * 
- * Revision 1.6  1994/11/02  07:31:36  billh
- * Added routines to set screen height and distance from origin.
- *
- * Revision 1.5  1994/10/05  03:36:24  dalke
- * fixed typo
- *
- * Revision 1.4  1994/10/04  20:29:22  billh
- * Changes to get to compile on HP's ... not there yet,though.
- *
- * Revision 1.3  1994/10/04  19:31:00  billh
- * Changed fsqrt to sqrtf.
- *
- * Revision 1.2  1994/09/28  17:05:05  billh
- * Added routines to get current distance to origin and screen height
- *
- * Revision 1.1  94/08/24  03:10:37  billh
- * Initial revision
- * 
  ***************************************************************************/
 #ifndef DISPLAYDEVICE_H
 #define DISPLAYDEVICE_H
@@ -75,6 +31,8 @@
 #include "ColorUser.h"
 #include "utilities.h"
 
+class PopupMenu;
+
 
 // constants for this object
 #define DISP_LIGHTS	4
@@ -89,6 +47,17 @@ public:
   // enum for left or right eye
   enum DisplayEye { NOSTEREO, LEFTEYE, RIGHTEYE };
 
+  // different buttons of the mouse
+  enum Buttons { B_LEFT, B_MIDDLE, B_RIGHT, B2_LEFT, B2_MIDDLE, B2_RIGHT,
+	B_F1, B_F2, B_F3, B_F4,  B_F5,  B_F6,
+	B_F7, B_F8, B_F9, B_F10, B_F11, B_F12,
+	B_ESC, TOTAL_BUTTONS };
+  
+  // possible window events
+  enum EventCodes { WIN_REDRAW, WIN_LEFT, WIN_MIDDLE, WIN_RIGHT,
+  	WIN_MOUSEX, WIN_MOUSEY, WIN_KEYBD,
+	WIN_UPDATE, WIN_INPUTCHANGE, WIN_EVENTCODES, WIN_NOEVENT };
+
 protected:
   //
   // flags for what capabilities this object has
@@ -129,7 +98,7 @@ protected:
   //
 
   float eyePos[3];		// current location of the viewer's eye
-  float nearClip, farClip;	// distance from eye to near and far clip plane
+  float nearClip, farClip;	// dist from eye to near and far clip plane
   float vSize;			// vertical size of 'screen'
   float zDist;			// distance to 'screen' relative to origin
   float Aspect;			// current aspect ratio
@@ -176,7 +145,7 @@ protected:
   // protected nonvirtual routines
   //
   
-  // calculate the position of the near frustrum plane, based on current values
+  // calculate the position of the near frustrum plane, based on curr values
   // of Aspect, vSize, zDist, nearClip and eyePosition
   void calc_frustrum(void);
 
@@ -211,6 +180,10 @@ public:
   DisplayDevice(char *);
   virtual ~DisplayDevice(void);
   
+  // copies over all relevant properties from one DisplayDevice
+  // to another
+  DisplayDevice& operator=(DisplayDevice &);
+
   //
   // query routines about the device's settings
   //
@@ -222,9 +195,49 @@ public:
   int aa_enabled(void) { return aaEnabled; }
   int cueing_enabled(void) { return cueingEnabled; }
 
+  //
+  // event handling routines
+  //
+
+  // queue the standard events (need only be called once ... but this is
+  // not done automatically by the window because it may not be necessary or
+  // even wanted)
+  virtual void queue_events(void);
+
+  // test if there is an event ready; if so, returns the type of event ready
+  virtual int test_events(void);
+
+  // read the next event ... returns an event type (one of the above ones),
+  // and a value.  Returns success, and sets arguments.
+  // NOTE: THIS SHOULD NOT BLOCK ... IT SHOUULD RETURN FALSE IF NO EVENT TO
+  // READ.
+  virtual int read_event(long &, long &);
+
+  // 
+  //
+  // get the current state of the device's pointer (i.e. cursor if it has one)
+  //
+
+  virtual int x(void);		// abs pos of cursor from lower-left corner
+  virtual int y(void);		// same, for y direction
+  virtual int button_down(int);	// whether a button is currently pressed
+
+  // allow the user to define a special shape for the cursor ... the data
+  // is assumed to consist of a single-dim array of 32 unsigned shorts; the
+  // first 16 define a 16x16-bit (row-major) pattern, the last 16 are a
+  // "second layer" which may be drawn in a different color
+  // args: which shape (>0, with 0 the "default" case which cannot be changed)
+  // the bitmap data, and the "hot spot" from the lower-left corner
+  virtual void change_cursor_shape(int, unsigned short *, int, int);
+
+  // set the Nth cursor shape as the current one.  If no arg given, the
+  // default shape (n=0) is used.
+  virtual void set_cursor(int = 0);
+
   //
   // get/set the background color
   //
+
   void get_background(float& r, float& g, float& b) {
     r = backColor[0];  g = backColor[1];  b = backColor[2];
   }
@@ -234,6 +247,24 @@ public:
     if(b >= 0.0 && b <= 1.0)  backColor[2] = b;
   }
 
+  //
+  // virtual routines to create and activate a popup (possibly pull-down) menu 
+  //
+
+  // given a PopupMenu definition, create it in the window (but do not
+  // activate it yet).  Return success.
+  virtual int menu_create(PopupMenu *);
+
+  // activate a previously-created menu.  If the windowing system has no
+  // current menu, or cannot do this operation, returns (-1); otherwise,
+  // returns the return code for the select (-1 if none selected).
+  virtual int menu_activate(void);
+
+  // delete the given menu from the display.
+  // If no argument is given, deletes the current menu (if any).
+  // Returns success.
+  virtual int menu_delete(PopupMenu * = NULL);
+
   //
   // routines to deal with the clipping planes and eye position
   //
@@ -483,3 +514,54 @@ public:
 };
 
 #endif
+
+/***************************************************************************
+ * REVISION HISTORY:
+ *
+ * $Log: DisplayDevice.h,v $
+ * Revision 1.11  1995/05/11  22:37:26  billh
+ * Moved log messages to the end of the file.
+ * Added virtual functions to queue and query events, as well as to test
+ * the state of buttons and to return the position of the cursor.
+ *
+ * Revision 1.10  95/03/24  18:48:59  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.9  1995/02/22  04:03:10  billh
+ * Added virtual routine pick, which checks the given draw list for points
+ * which can be selected.  Also added routines to convert absolute screen
+ * coords <--> relative scaled screen coords.
+ * Added virtual routine find_3D_from_2D, which takes a 3D point at pos A,
+ * and 2D rel screen position at B, and returns the 3D point corresponding
+ * to the 2D point at B in the same plane as point A.
+ *
+ * Revision 1.8  94/12/06  08:24:25  billh
+ * Added ability to create color categories, due to being now derived from
+ * ColorUser.
+ * Added routines to have a new color list specified, and to check for when
+ * a color in a relevant category is changed.
+ * 
+ * Revision 1.7  94/11/09  03:45:28  billh
+ * Provided default versions for all virtual functions, so an 'empty' display
+ * can be created that does essentially nothing (for testing purposes).
+ * 
+ * Revision 1.6  1994/11/02  07:31:36  billh
+ * Added routines to set screen height and distance from origin.
+ *
+ * Revision 1.5  1994/10/05  03:36:24  dalke
+ * fixed typo
+ *
+ * Revision 1.4  1994/10/04  20:29:22  billh
+ * Changes to get to compile on HP's ... not there yet,though.
+ *
+ * Revision 1.3  1994/10/04  19:31:00  billh
+ * Changed fsqrt to sqrtf.
+ *
+ * Revision 1.2  1994/09/28  17:05:05  billh
+ * Added routines to get current distance to origin and screen height
+ *
+ * Revision 1.1  94/08/24  03:10:37  billh
+ * Initial revision
+ * 
+ ***************************************************************************/
