@@ -11,7 +11,7 @@
  *
  *	$RCSfile: Displayable.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.15 $	$Date: 95/03/24 18:49:05 $
+ *	$Revision: 1.16 $	$Date: 1995/05/11 22:38:04 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -21,71 +21,6 @@
  * as 'children' to the parent, i.e. they get the parent's tranformation as
  * well as their own.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	Displayable.h,v $
- * Revision 1.15  95/03/24  18:49:05  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.14  1995/03/22  08:05:26  dalke
- * fixed insidious bug involving not knowing the initial
- * cmdList length after freeing linked list
- *
- * Revision 1.13  1995/03/17  22:27:25  billh
- * Added virtual function 'pickable_on' to indicate if a Pickable object
- * is currently being displayed.
- *
- * Revision 1.12  1995/02/22  03:57:58  billh
- * Now supports picking objects with a 2D or 3D pointer.
- * Displayable now derived from Pickable; some virtual functions supplied
- * by Displayble, and also unRegistering a Displayable also unRegisters it
- * from the PickList part of Scene.
- *
- * Revision 1.11  95/02/12  07:17:28  dalke
- * added code to clean the DLINKLIST links in the drawing list
- * 
- * Revision 1.10  1994/12/06  08:33:34  billh
- * All Displayable's now derived from ColorUser ... so each displayable can
- * be given a ColorList object to which color categories can be added,
- * and for each color category color objects can be made that hold a
- * colormap index.  The color editing commands can change which index is
- * associated with a name.
- *
- * Revision 1.9  94/10/12  20:08:16  dalke
- * Added "void set_rot(float x, char axis);"
- * 
- * Revision 1.8  1994/10/05  04:37:15  billh
- * Took out double backslash from text, even in comments.
- *
- * Revision 1.7  1994/10/01  03:04:32  billh
- * Removed 'update' routine.  Also made 'draw_prepare' call 'done_preparing'
- * in registered Scene's to signal preparations are done.
- *
- * Revision 1.6  94/09/26  18:54:43  billh
- * Lists of scenes and children now ResizeArray objects.
- * 
- * Revision 1.5  1994/09/23  00:45:43  billh
- * Fixed bug with destructor (was not removing children links).
- * draw_prepare and draw_update call corresponding routines in children.
- *
- * Revision 1.4  94/09/17  09:01:32  billh
- * Fixed bug so that children only register with a scene once.
- * 
- * Revision 1.3  94/09/15  02:05:22  billh
- * Children must get copies of parents transformation matrices at the start.
- * Also made 'set_name' a virtual function, so the Molecule class could use
- * the functionality as well.
- * 
- * Revision 1.2  94/09/14  04:11:33  billh
- * Now allows for 'child' Displayable objects for each Displayable; these
- * can have extra transformation effects, and only register their display
- * command list with a Scene.
- * 
- * Revision 1.1  1994/08/24  03:10:37  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef DISPLAYABLE_H
 #define DISPLAYABLE_H
@@ -95,10 +30,10 @@
 #include "ColorUser.h"
 #include "Pickable.h"
 #include "utilities.h"
-extern class DispCmd;
-extern class Displayable;
-extern class Scene;
-extern class DisplayDevice;
+class DispCmd;
+class Displayable;
+class Scene;
+class DisplayDevice;
 
 
 class Displayable : public ColorUser, public Pickable {
@@ -391,3 +326,72 @@ public:
 };
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: Displayable.h,v $
+ * Revision 1.16  1995/05/11  22:38:04  billh
+ * Moved log messages to the end of the file.
+ *
+ * Revision 1.15  95/03/24  18:49:05  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.14  1995/03/22  08:05:26  dalke
+ * fixed insidious bug involving not knowing the initial
+ * cmdList length after freeing linked list
+ *
+ * Revision 1.13  1995/03/17  22:27:25  billh
+ * Added virtual function 'pickable_on' to indicate if a Pickable object
+ * is currently being displayed.
+ *
+ * Revision 1.12  1995/02/22  03:57:58  billh
+ * Now supports picking objects with a 2D or 3D pointer.
+ * Displayable now derived from Pickable; some virtual functions supplied
+ * by Displayble, and also unRegistering a Displayable also unRegisters it
+ * from the PickList part of Scene.
+ *
+ * Revision 1.11  95/02/12  07:17:28  dalke
+ * added code to clean the DLINKLIST links in the drawing list
+ * 
+ * Revision 1.10  1994/12/06  08:33:34  billh
+ * All Displayable's now derived from ColorUser ... so each displayable can
+ * be given a ColorList object to which color categories can be added,
+ * and for each color category color objects can be made that hold a
+ * colormap index.  The color editing commands can change which index is
+ * associated with a name.
+ *
+ * Revision 1.9  94/10/12  20:08:16  dalke
+ * Added "void set_rot(float x, char axis);"
+ * 
+ * Revision 1.8  1994/10/05  04:37:15  billh
+ * Took out double backslash from text, even in comments.
+ *
+ * Revision 1.7  1994/10/01  03:04:32  billh
+ * Removed 'update' routine.  Also made 'draw_prepare' call 'done_preparing'
+ * in registered Scene's to signal preparations are done.
+ *
+ * Revision 1.6  94/09/26  18:54:43  billh
+ * Lists of scenes and children now ResizeArray objects.
+ * 
+ * Revision 1.5  1994/09/23  00:45:43  billh
+ * Fixed bug with destructor (was not removing children links).
+ * draw_prepare and draw_update call corresponding routines in children.
+ *
+ * Revision 1.4  94/09/17  09:01:32  billh
+ * Fixed bug so that children only register with a scene once.
+ * 
+ * Revision 1.3  94/09/15  02:05:22  billh
+ * Children must get copies of parents transformation matrices at the start.
+ * Also made 'set_name' a virtual function, so the Molecule class could use
+ * the functionality as well.
+ * 
+ * Revision 1.2  94/09/14  04:11:33  billh
+ * Now allows for 'child' Displayable objects for each Displayable; these
+ * can have extra transformation effects, and only register their display
+ * command list with a Scene.
+ * 
+ * Revision 1.1  1994/08/24  03:10:37  billh
+ * Initial revision
+ *
+ ***************************************************************************/
