@@ -11,7 +11,7 @@
  *
  *	$RCSfile: DrawPatch.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.2 $	$Date: 95/03/24 18:49:15 $
+ *	$Revision: 1.3 $	$Date: 1995/05/11 22:38:13 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -20,24 +20,13 @@
  * the configuration of any patches which have been stored for the current
  * timestep.  If no patch data is available, draws nothing.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	DrawPatch.h,v $
- * Revision 1.2  95/03/24  18:49:15  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.1  1994/11/09  03:23:05  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef DRAWPATCH_H
 #define DRAWPATCH_H
 
 #include "Displayable.h"
 #include "DispCmds.h"
-extern class DrawMolecule;
+class DrawMolecule;
 
 
 class DrawPatch : public Displayable3D {
@@ -87,3 +76,18 @@ public:
 extern char *patchDisplayMethodName[DrawPatch::TOTAL_PATCH_DISPLAY];
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: DrawPatch.h,v $
+ * Revision 1.3  1995/05/11  22:38:13  billh
+ * Moved log messages to the end of the file.
+ *
+ * Revision 1.2  95/03/24  18:49:15  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.1  1994/11/09  03:23:05  billh
+ * Initial revision
+ *
+ ***************************************************************************/
