@@ -11,7 +11,7 @@
  *
  *	$RCSfile: GLDisplayDevice.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.5 $	$Date: 95/03/24 18:49:30 $
+ *	$Revision: 1.6 $	$Date: 1995/05/11 22:49:03 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -20,27 +20,6 @@
  * different display devices that are GL-specific.  Will render drawing
  * commands into a single GL window.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	GLDisplayDevice.h,v $
- * Revision 1.5  95/03/24  18:49:30  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.4  1994/09/23  00:50:49  billh
- * Now derived from 'GLRenderer'; this level now just contains routines
- * to open a GL window and deal with stereo, projection, etc.
- *
- * Revision 1.3  94/09/03  11:05:29  dalke
- * added a square
- * 
- * Revision 1.2  1994/08/30  07:18:09  dalke
- * Added a triangle command
- *
- * Revision 1.1  1994/08/24  03:10:37  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef GLDISPLAYDEVICE_H
 #define GLDISPLAYDEVICE_H
@@ -76,6 +55,22 @@ public:
   GLDisplayDevice(int *size = NULL, int *loc = NULL);
   virtual ~GLDisplayDevice(void);
 
+  //
+  // event handling routines
+  //
+
+  // queue the standard events (need only be called once ... but this is
+  // not done automatically by the window because it may not be necessary or
+  // even wanted)
+  virtual void queue_events(void);
+
+  // test if there is an event ready
+  virtual int test_events(void);
+
+  // read the next event ... returns an event type (one of the above ones),
+  // and a value.  Returns success, and sets arguments.
+  virtual int read_event(long &, long &);
+
   //
   // routines to deal with stereo display
   //
@@ -99,3 +94,30 @@ public:
 };
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: GLDisplayDevice.h,v $
+ * Revision 1.6  1995/05/11  22:49:03  billh
+ * Added virtual functions to queue and check events, and to get/modify
+ * the cursor position, shape, etc.  All graphics/windowing-specific
+ * functions have now been moved to the DisplayDevice.
+ *
+ * Revision 1.5  95/03/24  18:49:30  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.4  1994/09/23  00:50:49  billh
+ * Now derived from 'GLRenderer'; this level now just contains routines
+ * to open a GL window and deal with stereo, projection, etc.
+ *
+ * Revision 1.3  94/09/03  11:05:29  dalke
+ * added a square
+ * 
+ * Revision 1.2  1994/08/30  07:18:09  dalke
+ * Added a triangle command
+ *
+ * Revision 1.1  1994/08/24  03:10:37  billh
+ * Initial revision
+ *
+ ***************************************************************************/
