@@ -11,7 +11,7 @@
  *
  *      $RCSfile: GeometryMol.h,v $
  *      $Author: billh $        $Locker:  $                $State: Exp $
- *      $Revision: 1.2 $      $Date: 95/03/24 18:50:00 $
+ *      $Revision: 1.4 $      $Date: 1995/05/11 22:59:17 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -21,25 +21,14 @@
  * on N atoms, and be able to calculate a single floating-point value for
  * those atoms.  (i.e. the angle formed by three atoms in space)
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	GeometryMol.h,v $
- * Revision 1.2  95/03/24  18:50:00  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.1  1995/03/04  05:33:08  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef GEOMETRYMOL_H
 #define GEOMETRYMOL_H
 
 #include "Geometry.h"
-extern class MoleculeList;
-extern class Molecule;
-extern class Displayable;
+class MoleculeList;
+class Molecule;
+class Displayable;
 
 
 class GeometryMol : public Geometry {
@@ -53,6 +42,7 @@ protected:
   
   // name of molecule geometry monitor
   char *gmName;
+  char *uniquegmName;
 
   //
   // protected functions
@@ -95,6 +85,10 @@ public:
   // return the name of this geometry marker; by default, just blank
   virtual char *name(void);
 
+  // return 'unique' name of the marker, which should be different than
+  // other names for different markers of this same type
+  virtual char *unique_name(void);
+
   // check whether the geometry value can still be calculated
   virtual int ok(void);
 
@@ -104,3 +98,26 @@ public:
 };
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: GeometryMol.h,v $
+ * Revision 1.4  1995/05/11  22:59:17  billh
+ * Moved log message to end of file.
+ *
+ * Revision 1.3  95/04/05  19:19:21  billh
+ * Fixed problem with specifying atoms to be picked when the name is not 
+ * unique ... the full atom name is now of the form "mol_id/atom_index",
+ * which is unique for all the atoms in the currently loaded molecules.
+ * Users can request an atom with the previous syntax, but that may not
+ * get the right atom due to the possibility of have two or more atoms
+ * in a single residue have the same atom name.
+ * 
+ * Revision 1.2  95/03/24  18:50:00  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.1  1995/03/04  05:33:08  billh
+ * Initial revision
+ *
+ ***************************************************************************/
