@@ -11,7 +11,7 @@
  *
  *	$RCSfile: Global.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.15 $	$Date: 95/03/24 18:50:04 $
+ *	$Revision: 1.19 $	$Date: 1995/05/13 01:36:00 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -19,10 +19,154 @@
  * Global data structures, configuration settings, and macros for the 
  * vmd library.
  *
- ***************************************************************************
- * REVISION HISTORY:
+ ***************************************************************************/
+#ifndef GLOBAL_DEFS_H
+#define GLOBAL_DEFS_H
+
+// standard includes for all modules
+#include "utilities.h"
+#include "config.h"
+#include "Inform.h"
+
+// the name of this program, and temp directory to use
+extern char *myName;
+extern char *myPath;
+extern char *myTempDir;
+extern char *dataPath;
+
+// location of the Babel executable (or NULL)
+extern char *vmdBabelBin;
+
+// name of the HTML viewer to use (or NULL if none)
+extern char *vmdHTMLViewer;
+
+// display device in which the images are rendered
+class DisplayDevice;
+extern DisplayDevice *display;
+
+// the list of all Displayable objects to draw
+class Scene;
+extern Scene *scene;
+
+// the list of all Lights which should be drawn
+class LightList;
+extern LightList *lights;
+
+// the list of all color objects (including material definitions)
+class ColorList;
+extern ColorList *colors;
+
+// axes and stage used in the scene
+class Axes;
+extern Axes *axes;
+class Stage;
+extern Stage *stage;
+
+// the command processor
+class CommandQueue;
+extern CommandQueue *commandQueue;
+
+// collection of all user interface objects
+class UIList;
+extern UIList *uiList;
+
+// the text interface
+class UIText;
+extern UIText *uiText;
+
+// the mouse used to manipulate the objects
+class Mouse;
+extern Mouse *mouse;
+
+// the global lists of all tools and trackers in maintained in UIVR
+class UIVR;
+extern UIVR *uiVR;
+
+// the global list of all molecules
+class MoleculeList;
+extern MoleculeList *moleculeList;
+
+// the global list of geometry labels
+class GeometryList;
+extern GeometryList *geometryList;
+
+// current remote setup object (only one is active at a time), and list of
+// running simulations
+#ifdef VMDREMOTE
+class Remote;
+extern Remote *remote;
+class RemoteList;
+extern RemoteList *remoteList;
+#endif
+
+// this allow text commands to be sent in via PVM messages
+#ifdef VMDEXTERNAL
+class UIExternal;
+extern UIExternal *uiExternal;
+#endif
+
+// resource to hold configuration values from a file
+class ConfigList;
+extern ConfigList *configList;
+
+// the different ways to record a scene to a file in some format
+class FileRenderList;
+extern FileRenderList *fileRenderList;
+
+/////////////////////////  external functions  
+
+// initialize the global variables and objects for the general library.
+// Must be passed command-line arguments to program.  Creates graphics
+// context and all associated objects, and then starts the UI, then adds any
+// commands that should be done at start.  When done, flushes command queue
+// and then returns, when the program is ready to start main event loop.
+extern void VMDinit(int, char *[]);
+
+// initialize the user interface ... called by VMDinit at start
+extern void VMDinitUI(void);
+
+// print out title message
+extern void VMDtitle(void);
+
+// given a string, return a new one with the temp dir name prepended.
+// This will use an internal static buffer, so it is NOT reentrant.
+extern char *VMDtempFile(const char *);
+
+// given a string, start up a HTML viewer with the string as an argument.
+// Return success.
+extern int VMDreadHTML(char *);
+
+// redraw the screen and update all things that need updatin'
+extern int VMDupdate(int);
+
+// exit the program normally with a message and exit code
+extern void VMDexit(char *, int);
+
+// exit the program abnormally with a message
+extern void VMDdie(char *);
+
+#endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: Global.h,v $
+ * Revision 1.19  1995/05/13  01:36:00  billh
+ * Help is now displayed by launching an HTML viewer (Mosaic by default)
+ * which will display the file /usr/local/lib/vmd/vmd_help.html
+ *
+ * Revision 1.18  95/05/11  22:50:17  billh
+ * Uses new Mouse constructor; uiVR now created in Global; added VMDGL
+ * option to allow separate specification of GUI and graphics methods.
+ * 
+ * Revision 1.17  95/04/06  17:54:50  dalke
+ * Finished interface
+ * 
+ * Revision 1.16  1995/04/04  21:05:44  billh
+ * Added VMDTMPDIR env variable, and routine VMDgetEnvironment for
+ * processing env variables.  Made global char string myTempDir to
+ * hold a directory for temporary files, and routine VMDtempFile to
+ * generate a temp filename from just a single string.
  *
- * $Log:	Global.h,v $
  * Revision 1.15  95/03/24  18:50:04  billh
  * Added copyright notice to top of file; made sure all virtual routines
  * are defined in the .C file, not in the .h file.
@@ -75,121 +219,3 @@
  * Initial revision
  *
  ***************************************************************************/
-#ifndef GLOBAL_DEFS_H
-#define GLOBAL_DEFS_H
-
-// standard includes for all modules
-#include "utilities.h"
-#include "config.h"
-#include "Inform.h"
-
-// the name of this program
-extern char *myName;
-extern char *myPath;
-
-// display device in which the images are rendered
-extern class DisplayDevice;
-extern DisplayDevice *display;
-
-// the list of all Displayable objects to draw
-extern class Scene;
-extern Scene *scene;
-
-// the list of all Lights which should be drawn
-extern class LightList;
-extern LightList *lights;
-
-// the list of all color objects (including material definitions)
-extern class ColorList;
-extern ColorList *colors;
-
-// axes and stage used in the scene
-extern class Axes;
-extern Axes *axes;
-extern class Stage;
-extern Stage *stage;
-
-// the command processor
-extern class CommandQueue;
-extern CommandQueue *commandQueue;
-
-// collection of all user interface objects
-extern class UIList;
-extern UIList *uiList;
-
-// the text interface
-extern class UIText;
-extern UIText *uiText;
-
-// the mouse used to manipulate the objects
-extern class Mouse;
-extern Mouse *mouse;
-
-// the global lists of all tools and trackers in maintained in UIVR
-extern class UIVR;
-extern UIVR *uiVR;
-
-// the global list of all molecules
-extern class MoleculeList;
-extern MoleculeList *moleculeList;
-
-// the global list of geometry labels
-extern class GeometryList;
-extern GeometryList *geometryList;
-
-// current remote setup object (only one is active at a time), and list of
-// running simulations
-#ifdef VMDREMOTE
-extern class Remote;
-extern Remote *remote;
-extern class RemoteList;
-extern RemoteList *remoteList;
-#endif
-
-// this allow text commands to be sent in via PVM messages
-#ifdef VMDEXTERNAL
-extern class UIExternal;
-extern UIExternal *uiExternal;
-#endif
-
-// resource to hold configuration values from a file
-extern class ConfigList;
-extern ConfigList *configList;
-
-// the different ways to record a scene to a file in some format
-extern class FileRenderList;
-extern FileRenderList *fileRenderList;
-
-/////////////////////////  external functions  
-
-// initialize the global variables and objects for the general library.
-// Must be passed command-line arguments to program.  Creates graphics
-// context and all associated objects, and then starts the UI, then adds any
-// commands that should be done at start.  When done, flushes command queue
-// and then returns, when the program is ready to start main event loop.
-extern void VMDinit(int, char *[]);
-
-// initialize the user interface ... called by VMDinit at start
-extern void VMDinitUI(void);
-
-// reads the definitions in the given init file at program start.
-// arguments are default path, and filename.
-extern void VMDreadInit(char *, char *);
-
-// sets text interface to read in the commands in the given file at startup
-// arguments are default path, and filename.
-extern void VMDreadStartup(ConfigList *, char *, char *);
-
-// print out title message
-extern void VMDtitle(void);
-
-// redraw the screen and update all things that need updatin'
-extern int VMDupdate(int);
-
-// exit the program normally with a message and exit code
-extern void VMDexit(char *, int);
-
-// exit the program abnormally with a message
-extern void VMDdie(char *);
-
-#endif
