@@ -11,37 +11,25 @@
  *
  *	$RCSfile: GrabTool.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.2 $	$Date: 95/03/24 18:50:07 $
+ *	$Revision: 1.3 $	$Date: 1995/05/11 22:51:40 $
  *
  ***************************************************************************
  * DESCRIPTION:
  *   This type of Tool can be used to pick up and manipulate molecules.
  * Just press button 0 to pick it up, and again to put it down
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	GrabTool.h,v $
- * Revision 1.2  95/03/24  18:50:07  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.1  1994/11/03  12:24:17  dalke
- * Initial revision
- *
+ * Simple grabbing tool, derived from Tool
+ * Draw a representation as a cylinder with silver cylindrival tip
+ * (supposed to be like a bar magnet)
+ * Use button 0 to grab onto the active molecules
+ * press again to release it
  ***************************************************************************/
 #ifndef GRABTOOL_H
 #define GRABTOOL_H
-// Simple grabbing tool, derived from Tool
-// Draw a representation as a cylinder with silver cylindrival tip
-//  (supposed to be like a bar magnet)
-// Use button 0 to grab onto the active molecules
-// press again to release it
 
 #include "Tool.h"
 
 class GrabTool : public Tool {
-public:
 
 private:
   // draw a cylinder with the given number of sides.
@@ -65,3 +53,18 @@ public:
 };
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: GrabTool.h,v $
+ * Revision 1.3  1995/05/11  22:51:40  billh
+ * Moved log messages to the end of the file.
+ *
+ * Revision 1.2  95/03/24  18:50:07  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.1  1994/11/03  12:24:17  dalke
+ * Initial revision
+ *
+ ***************************************************************************/
