@@ -11,7 +11,7 @@
  *
  *	$RCSfile: LightList.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.3 $	$Date: 95/03/24 18:50:21 $
+ *	$Revision: 1.4 $	$Date: 1995/05/11 23:02:02 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -19,31 +19,14 @@
  * A list of Light objects; used to select a single active one and allow
  * the user to manipulate it.  Also provides an initial set of default lights.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	LightList.h,v $
- * Revision 1.3  95/03/24  18:50:21  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.2  1995/01/30  21:02:56  billh
- * No longer derived from DLinkList; but routines put in to make it
- * LOOK like it is one, so the rest of the vmd code does not have to
- * be changed.  Now it just uses a simple array to store the Light
- * pointers, which is smaller and faster.
- *
- * Revision 1.1  1994/08/24  03:10:37  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef LIGHTLIST_H
 #define LIGHTLIST_H
 
 #include "Light.h"
 #include "DisplayDevice.h"
-extern class Scene;
-extern class Matrix4;
+class Scene;
+class Matrix4;
 
 // defines for this class
 #define MAX_DISP_LIGHTS		DISP_LIGHTS
@@ -125,3 +108,24 @@ public:
 };
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: LightList.h,v $
+ * Revision 1.4  1995/05/11  23:02:02  billh
+ * Moved log messages to end of file.
+ *
+ * Revision 1.3  95/03/24  18:50:21  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.2  1995/01/30  21:02:56  billh
+ * No longer derived from DLinkList; but routines put in to make it
+ * LOOK like it is one, so the rest of the vmd code does not have to
+ * be changed.  Now it just uses a simple array to store the Light
+ * pointers, which is smaller and faster.
+ *
+ * Revision 1.1  1994/08/24  03:10:37  billh
+ * Initial revision
+ *
+ ***************************************************************************/
