@@ -11,7 +11,7 @@
  *
  *	$RCSfile: NameList.c,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.2 $	$Date: 95/03/24 18:50:59 $
+ *	$Revision: 1.3 $	$Date: 1995/05/11 23:19:47 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -20,46 +20,7 @@
  * they are added.  For each name, which acts as a key, there is an associated
  * integer value.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	NameList.c,v $
- * Revision 1.2  95/03/24  18:50:59  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.1  1995/01/29  19:58:41  billh
- * Initial revision
- *
- * Revision 1.7  94/11/12  10:24:13  dalke
- * fixed up how spaces are deleted
- * 
- * Revision 1.6  1994/11/12  04:04:20  dalke
- * fixed problem with typecode
- *
- * Revision 1.5  1994/11/10  17:20:47  billh
- * Strips leading and trailing spaces from added names.
- *
- * Revision 1.4  94/11/02  01:37:23  billh
- * Added option to search for a name by just the first N characters, via
- * optional 2nd argument to 'name' and 'data'.
- * 
- * Revision 1.3  94/09/24  20:12:57  billh
- * Now a template; this is a basic associative array, with a character
- * string as the main lookup key, and a specified type for the data stored
- * for each name.
- * 
- * Revision 1.2  94/09/23  00:54:55  billh
- * names and Data now ResizeArray objects, instead of using a
- * linked list.  Much nicer, much shorter, and actually works.
- * 
- * Revision 1.1  94/09/17  09:11:36  billh
- * Initial revision
- * 
  ***************************************************************************/
-#ifdef ARCH_HPUX9
-  static char ident[] = "@(#)$Header: /private/auto143000131/vmdsrc/vmd/billh/src/RCS/NameList.c,v 1.2 95/03/24 18:50:59 billh Exp $";
-#endif
 
 #include <string.h>
 #include "ResizeArray.h"
@@ -257,3 +218,43 @@ void NameList<T>::set_data(int a, const T &val) {
 //    msgErr << sendmsg;
   }
 }
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: NameList.c,v $
+ * Revision 1.3  1995/05/11  23:19:47  billh
+ * Moved log messages to end of file.
+ *
+ * Revision 1.2  95/03/24  18:50:59  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.1  1995/01/29  19:58:41  billh
+ * Initial revision
+ *
+ * Revision 1.7  94/11/12  10:24:13  dalke
+ * fixed up how spaces are deleted
+ * 
+ * Revision 1.6  1994/11/12  04:04:20  dalke
+ * fixed problem with typecode
+ *
+ * Revision 1.5  1994/11/10  17:20:47  billh
+ * Strips leading and trailing spaces from added names.
+ *
+ * Revision 1.4  94/11/02  01:37:23  billh
+ * Added option to search for a name by just the first N characters, via
+ * optional 2nd argument to 'name' and 'data'.
+ * 
+ * Revision 1.3  94/09/24  20:12:57  billh
+ * Now a template; this is a basic associative array, with a character
+ * string as the main lookup key, and a specified type for the data stored
+ * for each name.
+ * 
+ * Revision 1.2  94/09/23  00:54:55  billh
+ * names and Data now ResizeArray objects, instead of using a
+ * linked list.  Much nicer, much shorter, and actually works.
+ * 
+ * Revision 1.1  94/09/17  09:11:36  billh
+ * Initial revision
+ * 
+ ***************************************************************************/
