@@ -11,7 +11,7 @@
  *
  *      $RCSfile: PickModeMolLabel.h,v $
  *      $Author: billh $        $Locker:  $                $State: Exp $
- *      $Revision: 1.2 $      $Date: 95/03/24 18:51:12 $
+ *      $Revision: 1.3 $      $Date: 1995/05/11 23:31:24 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -22,23 +22,12 @@
  * more atoms are selected, they are remembered until enough have been picked
  * to create the relevant label (i.e. 3 atoms to create an Angle label).
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	PickModeMolLabel.h,v $
- * Revision 1.2  95/03/24  18:51:12  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.1  1995/03/04  05:33:08  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef PICKMODEMOLLABEL_H
 #define PICKMODEMOLLABEL_H
 
 #include "PickMode.h"
-extern class Molecule;
+class Molecule;
 
 
 class PickModeMolLabel : public PickMode {
@@ -110,3 +99,18 @@ public:
 };
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: PickModeMolLabel.h,v $
+ * Revision 1.3  1995/05/11  23:31:24  billh
+ * Moved log messages to end of file.
+ *
+ * Revision 1.2  95/03/24  18:51:12  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.1  1995/03/04  05:33:08  billh
+ * Initial revision
+ *
+ ***************************************************************************/
