@@ -11,7 +11,7 @@
  *
  *	$RCSfile: Remote.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.6 $	$Date: 95/03/24 18:51:33 $
+ *	$Revision: 1.7 $	$Date: 1995/05/11 23:42:33 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -19,37 +19,13 @@
  * The Remote object, which maintains a connection to a remote computer that
  * provides data and structures.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	Remote.h,v $
- * Revision 1.6  95/03/24  18:51:33  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.5  1994/11/10  17:19:25  billh
- * Added option to save every Nth transferred frame.
- *
- * Revision 1.4  1994/11/02  01:36:40  billh
- * When receiving a timestep, must call 'get_next_ts' in Remote first, get
- * all the data, and when done, call 'done_with_ts' in Remote.
- *
- * Revision 1.3  94/10/21  03:51:20  billh
- * Several bug fixes, and added routines to get and change settings.
- * 
- * Revision 1.2  1994/10/01  11:01:37  billh
- * Several bug fixes due to putting in MoleculeRemote code.
- *
- * Revision 1.1  94/10/01  03:08:43  billh
- * Initial revision
- *  
  ***************************************************************************/
 #ifndef REMOTE_H
 #define REMOTE_H
 
 #include "mdcomm.h"
 #include "mdc_errno.h"
-extern class MoleculeRemote;
+class MoleculeRemote;
 
 // variables for accessing the error variables in mdcomm
 extern "C" {
@@ -347,3 +323,31 @@ extern char *remoteSettingKeyword[Remote::TOTAL_SETTINGS];
 extern char  remoteSettingType[Remote::TOTAL_SETTINGS];
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: Remote.h,v $
+ * Revision 1.7  1995/05/11  23:42:33  billh
+ * Moved log messages to end of file.
+ *
+ * Revision 1.6  95/03/24  18:51:33  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.5  1994/11/10  17:19:25  billh
+ * Added option to save every Nth transferred frame.
+ *
+ * Revision 1.4  1994/11/02  01:36:40  billh
+ * When receiving a timestep, must call 'get_next_ts' in Remote first, get
+ * all the data, and when done, call 'done_with_ts' in Remote.
+ *
+ * Revision 1.3  94/10/21  03:51:20  billh
+ * Several bug fixes, and added routines to get and change settings.
+ * 
+ * Revision 1.2  1994/10/01  11:01:37  billh
+ * Several bug fixes due to putting in MoleculeRemote code.
+ *
+ * Revision 1.1  94/10/01  03:08:43  billh
+ * Initial revision
+ *  
+ ***************************************************************************/
