@@ -11,7 +11,7 @@
  *
  *	$RCSfile: Scene.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.8 $	$Date: 95/03/24 18:51:45 $
+ *	$Revision: 1.10 $	$Date: 1995/05/11 23:57:04 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -29,48 +29,13 @@
  * mode are told of the picking result.  This capability is inherited from
  * PickList.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	Scene.h,v $
- * Revision 1.8  95/03/24  18:51:45  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.7  1995/02/22  03:57:58  billh
- * Now supports picking objects with a 2D or 3D pointer.
- * Scene now derived from PickList.
- *
- * Revision 1.6  94/12/06  08:26:45  billh
- * Added routine color_changed, which simply calls this same routine
- * for all registered objects.  color_changed is called when a color in a
- * specific category is changed.
- * 
- * Revision 1.5  94/11/24  07:27:03  dalke
- * Added filedraw for writing the scene to some external graphics format
- * 
- * Revision 1.4  1994/10/01  03:06:53  billh
- * New format; Scene now a more general base class, from which are derived
- * NormalScene and CaveScene (for starters ...)
- *
- * Revision 1.3  94/09/29  19:27:11  dalke
- * Added mem. alloc/free functions so I can use shared mem.
- * Split draw routine up into prepare/draw/update
- * 
- * Revision 1.2  1994/09/14  03:55:10  billh
- * Changed due to restructuring of Displayable ... now calls
- * 'draw_prepare' and 'draw_update' for Displayable's.
- *
- * Revision 1.1  94/08/24  03:10:37  billh
- * Initial revision
- * 
  ***************************************************************************/
 #ifndef SCENE_H
 #define SCENE_H
 
 #include "PickList.h"
 #include "Displayable.h"
-extern class DisplayDevice;
+class DisplayDevice;
 
 
 class Scene : public PickList {
@@ -83,7 +48,7 @@ protected:
   int numCmdLists2D, numCmdLists3D;
 
   // are we rocking the objects back and forth?  If so, what, where, and how?
-  int Rocking, rockSteps, currRockStep;
+  int Rocking, rockSteps, currRockStep, rockOnce;
   char rockAxis;
   float rockAmount;
 
@@ -197,14 +162,52 @@ public:
 
   void stop_rocking(void) { Rocking = FALSE; }
   void resume_rocking(void) { Rocking = TRUE; }
-  void start_rocking(float a = 1.0, char ax = 'y', int steps = 180) {
-    Rocking = TRUE;
-    rockSteps = steps;		// if < 0, continuous
-    currRockStep = 0;		// when == rockSteps, flip rockAmount
-    rockAmount = a;
-    rockAxis = ((ax >= 'x' && ax <= 'z') ? ax : 'y');
-  }
-  
+  void start_rocking(float a = 1.0, char ax = 'y', int steps = 180,
+  			int doOnce = FALSE);
+
 };
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: Scene.h,v $
+ * Revision 1.10  1995/05/11  23:57:04  billh
+ * Moved log messages to end of file.
+ *
+ * Revision 1.9  95/03/31  16:01:44  billh
+ * Moved start_rocking routine to .C file; added ability to rock just
+ * once, so that a smooth rotation from a --> can be done.
+ * 
+ * Revision 1.8  95/03/24  18:51:45  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.7  1995/02/22  03:57:58  billh
+ * Now supports picking objects with a 2D or 3D pointer.
+ * Scene now derived from PickList.
+ *
+ * Revision 1.6  94/12/06  08:26:45  billh
+ * Added routine color_changed, which simply calls this same routine
+ * for all registered objects.  color_changed is called when a color in a
+ * specific category is changed.
+ * 
+ * Revision 1.5  94/11/24  07:27:03  dalke
+ * Added filedraw for writing the scene to some external graphics format
+ * 
+ * Revision 1.4  1994/10/01  03:06:53  billh
+ * New format; Scene now a more general base class, from which are derived
+ * NormalScene and CaveScene (for starters ...)
+ *
+ * Revision 1.3  94/09/29  19:27:11  dalke
+ * Added mem. alloc/free functions so I can use shared mem.
+ * Split draw routine up into prepare/draw/update
+ * 
+ * Revision 1.2  1994/09/14  03:55:10  billh
+ * Changed due to restructuring of Displayable ... now calls
+ * 'draw_prepare' and 'draw_update' for Displayable's.
+ *
+ * Revision 1.1  94/08/24  03:10:37  billh
+ * Initial revision
+ * 
+ ***************************************************************************/
