@@ -11,34 +11,12 @@
  *
  *      $RCSfile: TrackerList.h,v $
  *      $Author: billh $        $Locker:  $                $State: Exp $
- *      $Revision: 1.5 $      $Date: 95/03/24 18:52:15 $
+ *      $Revision: 1.6 $      $Date: 1995/05/11 23:46:25 $
  *
  ***************************************************************************
  * DESCRIPTION:
  *   Maintain a list of trackers.  Trackers can only be added to the list!
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	TrackerList.h,v $
- * Revision 1.5  95/03/24  18:52:15  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.4  1994/10/05  06:56:30  dalke
- * Changed from DLinkList to ResizeArray
- *
- * Revision 1.3  1994/09/17  09:42:35  dalke
- * Took TrackerList out of UIList and into UIVR.
- * Added code to start_avail to associate sensors with "buttons"
- *
- * Revision 1.2  1994/09/07  07:48:31  dalke
- * various name changes, made TrackerList part of UIObject class,
- * and more - still writing
- *
- * Revision 1.1  1994/09/03  11:19:09  dalke
- * Initial revision
- *
  ***************************************************************************/
 #ifndef TRACKERLIST_H
 #define TRACKERLIST_H
@@ -46,8 +24,9 @@
 #include "Tracker.h"
 #include "ResizeArray.h"
 
+
 class TrackerList {
-private:
+public:
   // list of trackers which can be started
 typedef struct AvailTrackertypestruct {
   char *visiblename; // name the user sees
@@ -121,3 +100,29 @@ private:
 };
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: TrackerList.h,v $
+ * Revision 1.6  1995/05/11  23:46:25  billh
+ * Updated due to changes in Buttons; moved log message to end of file.
+ *
+ * Revision 1.5  95/03/24  18:52:15  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.4  1994/10/05  06:56:30  dalke
+ * Changed from DLinkList to ResizeArray
+ *
+ * Revision 1.3  1994/09/17  09:42:35  dalke
+ * Took TrackerList out of UIList and into UIVR.
+ * Added code to start_avail to associate sensors with "buttons"
+ *
+ * Revision 1.2  1994/09/07  07:48:31  dalke
+ * various name changes, made TrackerList part of UIObject class,
+ * and more - still writing
+ *
+ * Revision 1.1  1994/09/03  11:19:09  dalke
+ * Initial revision
+ *
+ ***************************************************************************/
