@@ -11,7 +11,7 @@
  *
  *	$RCSfile: UIList.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.5 $	$Date: 95/03/24 18:52:22 $
+ *	$Revision: 1.6 $	$Date: 1995/05/12 00:10:52 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -22,27 +22,6 @@
  *  event loop, these UIs are told, first, to check for any events that
  *  occured and put commands on the command queue.  After that step, the
  *  commands are executed and the UIs told about the results of each.
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	UIList.h,v $
- * Revision 1.5  95/03/24  18:52:22  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.4  1994/10/05  07:05:23  billh
- * moved some routines to .C file.
- *
- * Revision 1.3  1994/10/05  06:58:16  billh
- * Converted to use a ResizeArray instead of a DLinkList in the command queue
- * and ui list.
- *
- * Revision 1.2  1994/10/04  20:29:22  billh
- * Changes to get to compile on HP's ... not there yet,though.
- *
- * Revision 1.1  1994/08/24  03:10:37  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef UILIST_H
 #define UILIST_H
@@ -50,7 +29,7 @@
 #include "ResizeArray.h"
 #include "Command.h"
 #include "utilities.h"
-extern class UIObject;
+class UIObject;
 
 /* NOTES:
  *	1) When a UIObject is created, it should be registered with a UIList.
@@ -102,3 +81,28 @@ public:
 };  // end class description for UIList
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: UIList.h,v $
+ * Revision 1.6  1995/05/12  00:10:52  billh
+ * Moved log messages to end of file.
+ *
+ * Revision 1.5  95/03/24  18:52:22  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.4  1994/10/05  07:05:23  billh
+ * moved some routines to .C file.
+ *
+ * Revision 1.3  1994/10/05  06:58:16  billh
+ * Converted to use a ResizeArray instead of a DLinkList in the command queue
+ * and ui list.
+ *
+ * Revision 1.2  1994/10/04  20:29:22  billh
+ * Changes to get to compile on HP's ... not there yet,though.
+ *
+ * Revision 1.1  1994/08/24  03:10:37  billh
+ * Initial revision
+ *
+ ***************************************************************************/
