@@ -11,7 +11,7 @@
  *
  *	$RCSfile: UIObject.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.4 $	$Date: 1995/03/28 03:46:54 $
+ *	$Revision: 1.5 $	$Date: 1995/05/12 00:00:12 $
  *
  ***************************************************************************
  * DESCRIPTION:
@@ -21,35 +21,15 @@
  * and 'signing up' for which commands it is interested in, as well as
  * generating commands and events.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log: UIObject.h,v $
- * Revision 1.4  1995/03/28  03:46:54  billh
- * Added 'runcommand' routine, to allow a UIObject to request a command be
- * immediately executed instead of going on the queue.
- *
- * Revision 1.3  95/03/24  18:52:24  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.2  1994/10/19  20:23:08  billh
- * Made 'On' and 'Off' virtual routines in every UIObject, and added virtual
- * routine 'is_on' to test for whether the ui is on or off (used mainly by
- * Mouse to provide options to toggle forms on and off)
- *
- * Revision 1.1  1994/08/24  03:10:37  billh
- * Initial revision
- *
  ***************************************************************************/
 #ifndef UIOBJECT_H
 #define UIOBJECT_H
 
 #include "utilities.h"
 #include "Inform.h"
-extern class UIList;
-extern class CommandQueue;
-extern class Command;
+class UIList;
+class CommandQueue;
+class Command;
 
 
 class UIObject {
@@ -120,7 +100,7 @@ public:
   
   //
   // virtual routines to provide information about the UIObject, and turn
-  // it on or off
+  // it on or off, or change its position
   //
 
   // is this a menu object?
@@ -135,6 +115,14 @@ public:
   // turn off UI (don't allow it to issue commands)
   virtual void Off(void);
 
+  // move the UI object to a new position (may not be applicable)
+  virtual void move(int, int);
+  virtual void move(float *);		// may be used for 3D objects
+
+  // return where the object is; if not applicable, does nothing
+  virtual void where(int &, int &);
+  virtual void where(float *);
+
   //
   // virtual routines for UI init/display
   //
@@ -165,3 +153,27 @@ public:
 };
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: UIObject.h,v $
+ * Revision 1.5  1995/05/12  00:00:12  billh
+ * Moved log messages to end of file.
+ *
+ * Revision 1.4  95/03/28  03:46:54  billh
+ * Added 'runcommand' routine, to allow a UIObject to request a command be
+ * immediately executed instead of going on the queue.
+ * 
+ * Revision 1.3  95/03/24  18:52:24  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.2  1994/10/19  20:23:08  billh
+ * Made 'On' and 'Off' virtual routines in every UIObject, and added virtual
+ * routine 'is_on' to test for whether the ui is on or off (used mainly by
+ * Mouse to provide options to toggle forms on and off)
+ *
+ * Revision 1.1  1994/08/24  03:10:37  billh
+ * Initial revision
+ *
+ ***************************************************************************/
