@@ -11,47 +11,19 @@
  *
  *	$RCSfile: utilities.h,v $
  *	$Author: billh $	$Locker:  $		$State: Exp $
- *	$Revision: 1.8 $	$Date: 95/03/24 18:52:53 $
+ *	$Revision: 1.11 $	$Date: 1995/05/12 00:15:04 $
  *
  ***************************************************************************
  * DESCRIPTION:
  *
  * General utility routines and definitions.
  *
- ***************************************************************************
- * REVISION HISTORY:
- *
- * $Log:	utilities.h,v $
- * Revision 1.8  95/03/24  18:52:53  billh
- * Added copyright notice to top of file; made sure all virtual routines
- * are defined in the .C file, not in the .h file.
- * 
- * Revision 1.7  1995/03/04  05:06:34  billh
- * added midpoint and angle routines.
- *
- * Revision 1.6  94/11/02  05:19:23  dalke
- * Added str2bool - a string to boolean converter
- * 
- * Revision 1.5  1994/09/23  07:47:56  dalke
- * Rearranges the vector operations
- *
- * Revision 1.4  1994/09/16  21:34:14  dalke
- * added norm
- *
- * Revision 1.3  1994/09/16  21:26:44  dalke
- * added subtraction of vectors
- *
- * Revision 1.2  1994/09/03  11:06:29  dalke
- * added cross product and normalizing functions
- *
- * Revision 1.1  1994/08/24  03:10:37  billh
- * Initial revision
- *
  ***************************************************************************/
-
 #ifndef UTILITIES_H
 #define UTILITIES_H
 
+#include <string.h>
+
 #ifndef FALSE
 #define FALSE 0
 #define TRUE  1
@@ -70,8 +42,15 @@
 #define TWOPI   2.0 * PI
 #endif
 
+
+// given an argc, argv pair, take all the arguments from the Nth one on
+// and combine them into a single string with spaces separating words.  This
+// allocates space for the string, which must be freed by the user.
+extern char *combine_arguments(int, char **, int);
+
+
 // make a copy of a string using c++ new routine for memory alloc
-extern char *stringdup(char *);
+extern char *stringdup(const char *);
 
 
 // convert the given string to upper case
@@ -118,6 +97,11 @@ inline float dot_prod(float *v1, float *v2)
  return v1[0]* v2[0] + v1[1]* v2[1] + v1[2] * v2[2];
 }
 
+// copy the first 3 elements from v2 to v2
+inline void copy(float *v1, float *v2)
+{
+ memcpy(v1, v2, 3*sizeof(float));
+}
 
 // normalizes the 3-vector to length one and returns the pointer
 // note that this changes the vector
@@ -159,3 +143,42 @@ extern float norm(float *);
 extern int str2bool(const char *s);
 
 #endif
+
+/* REVISION HISTORY:********************************************************
+ *
+ * $Log: utilities.h,v $
+ * Revision 1.11  1995/05/12  00:15:04  billh
+ * Moved log messages to end of file.
+ *
+ * Revision 1.10  95/04/10  09:17:49  dalke
+ * added a vector-like copy
+ * 
+ * Revision 1.9  1995/04/04  21:00:13  billh
+ * stringdup now takes arg static char pointer
+ *
+ * Revision 1.8  95/03/24  18:52:53  billh
+ * Added copyright notice to top of file; made sure all virtual routines
+ * are defined in the .C file, not in the .h file.
+ * 
+ * Revision 1.7  1995/03/04  05:06:34  billh
+ * added midpoint and angle routines.
+ *
+ * Revision 1.6  94/11/02  05:19:23  dalke
+ * Added str2bool - a string to boolean converter
+ * 
+ * Revision 1.5  1994/09/23  07:47:56  dalke
+ * Rearranges the vector operations
+ *
+ * Revision 1.4  1994/09/16  21:34:14  dalke
+ * added norm
+ *
+ * Revision 1.3  1994/09/16  21:26:44  dalke
+ * added subtraction of vectors
+ *
+ * Revision 1.2  1994/09/03  11:06:29  dalke
+ * added cross product and normalizing functions
+ *
+ * Revision 1.1  1994/08/24  03:10:37  billh
+ * Initial revision
+ *
+ ***************************************************************************/
